@@ -271,7 +271,7 @@ class Local(object):
         return (changed, deleted)
 
 
-    def build(self, roles=None):
+    def build(self, roles=None, render_templates=True):
         '''Build a set of roles on this host, storing the snapshot of what will be done in $path/.build/'''
         unlock = self.lock()
         if roles is None:
@@ -284,7 +284,7 @@ class Local(object):
         shutil.rmtree(self.build_path, True)
 
         for role in roles:
-            self.role(role).build()
+            self.role(role).build(render_templates)
 
         #For the sake of the build directory being a single, complete snapshot of what will be installed, serialize the package list to the metadata directory
         meta_path = os.path.join(self.build_path, '.bishop')
@@ -357,7 +357,7 @@ class Local(object):
 
         if self.repo is not None:
             self.mirror(list(set(self.roles).union(set(roles))))
-        self.build(roles)
+        self.build(roles, render_templates=not cleanup)
 
         change_packages = self.get_new_packages()
         self.run_prepackages(change_packages)
