@@ -22,7 +22,6 @@ def setup_test():
     if not os.path.isdir('test/test-repo/rolepostinst/files/etc/empty-dir'):
         os.makedirs('test/test-repo/rolepostinst/files/etc/empty-dir', 0755)
     
-    open('/tmp/setup-calls.log', 'a').write('setting up...\n')
     host = bishop.host.Local(path='test/test-repo')
 
 def teardown_test():
@@ -87,3 +86,12 @@ def test_build_node():
     host.roles = ['role2']
     host.build()
     assert os.path.exists('test/test-repo/.build/etc/sample.conf')
+
+@tools.with_setup(setup_test, teardown_test)
+def test_build_order():
+    host.roles = ['order4', 'order3']
+    host.build()
+    assert host.ordered_roles == ['order1', 'order2', 'order3', 'order4']
+
+    sorted_scripts = host.script_order({'test/test-repo/order1/postinst': [], 'test/test-repo/order2/postinst': []})
+    assert('order1' in sorted_scripts[0][0] and 'order2' in sorted_scripts[1][0])
